
        
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2014 Saxonica Limited.
// This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
// If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
// This Source Code Form is "Incompatible With Secondary Licenses", as defined by the Mozilla Public License, v. 2.0.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////        

        package net.sf.saxon.lib;

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


/**
 * FeatureKeys defines a set of constants, representing the names of Saxon configuration
 * options which can be supplied to the Saxon implementations of the JAXP
 * interfaces TransformerFactory, SchemaFactory, Validator, and ValidationHandler,
 * and to other interfaces such as the s9api {@link net.sf.saxon.s9api.Processor}
 *
 * @author Michael H. Kay
 */
 
 public abstract class FeatureKeys {

        
    /**
    *            <p>ALLOW_EXTERNAL_FUNCTIONS determines whether calls to reflexive external functions are
    *                allowed. More specifically, if set to <b>false</b> it disallows all of the
    *                following:</p>
    *
    *            <ul>
    *                <li>Calls to reflexive Java extension functions</li>
    *                <li>Use of the XSLT <code>system-property()</code> function to access Java system
    *                    properties</li>
    *                <li>Use of a relative URI in the <code>xsl:result-document</code> instruction</li>
    *                <li>Calls to XSLT extension instructions</li>
    *            </ul>
    *
    *            <p>The default value is <b>true</b>. The setting <b>false</b> is recommended in an
    *                environment where untrusted stylesheets may be executed.</p>
    *
    *            <p>This option does not disable use of the <code>doc()</code> function or similar
    *                functions to access the filestore of the machine where the transformation or query
    *                is running. That should be done using a user-supplied <code>URIResolver</code>.</p>
    *
    *            <p>Note that integrated extension functions are trusted; calls to such functions are
    *                allowed even if this configuration option is false. In cases where an integrated
    *                extension function is used to load and execute untrusted code, it should check this
    *                configuration option before doing so.</p>
    *        
    **/

    public final static String ALLOW_EXTERNAL_FUNCTIONS = 
        "http://saxon.sf.net/feature/allow-external-functions";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>ALLOW_MULTITHREADING determines whether multi-threading is allowed.</p>
    *            <p>If true (the default), the presence of the attribute <code>saxon:threads="N"</code>
    *                on an <code>xsl:for-each</code> instruction, when running under Saxon-EE, causes
    *                multi-threaded execution. If set to false, the value of the
    *                    <code>saxon:threads</code> argument is ignored.</p>
    *            <p>Setting the value to false also disables asynchronous processing of
    *                    <code>xsl:result-document</code> instructions.</p>
    *            <p>The default value is true if Saxon-EE is in use, false otherwise.</p>
    *        
    **/

    public final static String ALLOW_MULTITHREADING = 
        "http://saxon.sf.net/feature/allow-multithreading";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>ALLOW_OLD_JAVA_URI_FORMAT determines whether extension function calls to
    *                dynamically-loaded Java extension functions may use the URI format supported in
    *                older Saxon releases.</p>
    *            <p>If the value is false (the default), the only URI format accepted is (for example)
    *                "java:java.util.Date" - that is, a URI consisting of the string "java:" followed by
    *                the Java qualified class name of the class containing the implementation of the
    *                extension function.</p>
    *            <p>If the value is true, then in addition to this format, the following are accepted:
    *                (a) the Java class name on its own ("java.util.Date"), and (b) any URI in which the
    *                Java class name follows the last "/" character (for example
    *                "http://my.com/extensions/java.util.Date"). This last format was originally provided
    *                for compatibility with xt and xalan, but it causes problems because it leads to
    *                unnecessary attempts to load spurious classes when the user did not intend the URI
    *                to represent a dynamically-loaded Java class.</p>
    *        
    **/

    public final static String ALLOW_OLD_JAVA_URI_FORMAT = 
        "http://saxon.sf.net/feature/allow-old-java-uri-format";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>ASSERTIONS_CAN_SEE_COMMENTS determines whether comment and processing instructions in
    *                a document being validated are visible to assertions in an XSD 1.1 schema.</p>
    *            <p>If the value is false (the default), comments and processing instructions are
    *                stripped from the view of the document that is made visible to the XPath expression
    *                that implements the assertion. If this creates adjacent text nodes, they are
    *                collapsed into a single text node.</p>
    *            <p>If the value is true, then comments and processing instructions are visible to the
    *                XPath assertion.</p>
    *        
    **/

    public final static String ASSERTIONS_CAN_SEE_COMMENTS = 
        "http://saxon.sf.net/feature/assertionsCanSeeComments";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The supplied <code>CollationURIResolver</code> is used to process any collation URIs
    *                found in the query or stylesheet, returning an object of class
    *                    {@link StringCollator} that implements the requested collation.</p>
    *        
    **/

    public final static String COLLATION_URI_RESOLVER = 
        "http://saxon.sf.net/feature/collation-uri-resolver";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The supplied class is instantiated and the resulting instance is used as the value of
    *                the {@link FeatureKeys#COLLATION_URI_RESOLVER} property.</p>
    *        
    **/

    public final static String COLLATION_URI_RESOLVER_CLASS = 
        "http://saxon.sf.net/feature/collation-uri-resolver-class";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The supplied <code>CollectionURIResolver</code> is used to process any URIs used in
    *                calls to the <code>collection()</code> function. The
    *                    <code>CollectionURIResolver</code> may either return a sequence of URIs (which
    *                are then resolved in the same way as URIs passed to the <code>doc()</code>
    *                function), or it may return a sequence of (typically document) nodes.</p>
    *        
    **/

    public final static String COLLECTION_URI_RESOLVER = 
        "http://saxon.sf.net/feature/collection-uri-resolver";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The supplied class is instantiated and the resulting instance is used as the value of
    *                the {@link FeatureKeys#COLLECTION_URI_RESOLVER} property.</p>
    *        
    **/

    public final static String COLLECTION_URI_RESOLVER_CLASS = 
        "http://saxon.sf.net/feature/collection-uri-resolver-class";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>If run-time tracing of stylesheet or query execution is required, then the code must
    *                be compiled with tracing enabled. Default is false. This option causes code to be
    *                compiled that makes calls to a {@link net.sf.saxon.lib.TraceListener}, but this
    *                has no effect unless a <code>TraceListener</code> is registered at execution
    *                time.</p>
    *        
    **/

    public final static String COMPILE_WITH_TRACING = 
        "http://saxon.sf.net/feature/compile-with-tracing";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This attribute cannot be set on the {@link net.sf.saxon.Configuration} itself,
    *                but it can be set on various JAXP factory objects such as a
    *                    <code>TransformerFactory</code> or <code>DocumentBuilderFactory</code>, to
    *                ensure that several such factories use the same <code>Configuration</code>. Note
    *                that other configuration options are held in the <code>Configuration</code> object,
    *                so setting this attribute will cancel all others that have been set. Also, if two
    *                factories share the same <code>Configuration</code>, then setting an attribute on
    *                one affects all the others.</p>
    *        
    **/

    public final static String CONFIGURATION = 
        "http://saxon.sf.net/feature/configuration";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Defines a configuration file to be applied to the configuration. This attribute
    *                cannot be set on the {@link net.sf.saxon.Configuration} itself, but it can be
    *                set on various JAXP factory objects such as a <code>TransformerFactory</code> or
    *                    <code>DocumentBuilderFactory</code>. It is particularly useful when running
    *                transformations via the Ant xslt task, where it can be set as follows to define all
    *                configuration settings: </p>
    *            <p>
    *                <code><factory name="net.sf.saxon.TransformerFactoryImpl"> <attribute
    *                    name="http://saxon.sf.net/feature/configuration-file"
    *                    value="c:/saxon/config.xml"/> </factory></code>
    *            </p>
    *        
    **/

    public final static String CONFIGURATION_FILE = 
        "http://saxon.sf.net/feature/configuration-file";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option is set to indicate that bytecode generation should be run in debugging
    *                mode; it injects diagnostic tracing calls into the generated bytecode. This should
    *                be used only if requested by Saxonica support to diagnose a problem related to
    *                bytecode generation.</p>
    *        
    **/

    public final static String DEBUG_BYTE_CODE = 
        "http://saxon.sf.net/feature/debugByteCode";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option is relevant only if <code>DISPLAY_BYTE_CODE</code> is set to true. It
    *                defines a directory to which files containing bytecode in human-readable form will
    *                be written. There will be one such file for each generated class, with a filename
    *                designed to give some kind of clue as to its relationship to the source code.</p>
    *            <p>The default value is the directory <code>saxonByteCode</code> within the current
    *                working directory.</p>
    *            <p>The named directory is created if it does not already exist.</p>
    *            <p>Because the generation of class names involves random numbers, files will tend to
    *                accumulate in the supplied directory, even when the same source code is compiled
    *                repeatedly.</p>
    *        
    **/

    public final static String DEBUG_BYTE_CODE_DIR = 
        "http://saxon.sf.net/feature/debugByteCodeDir";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option determines the collation that is used for comparing strings when no
    *                explicit collation is requested. It is not necessary for this collation to exist (or
    *                to have been registered) when setting this option; it only needs to exist by the
    *                time it is used.</p>
    *            <p>In XSLT it is possible to override this setting using the
    *                    <code>[xsl:]default-collation</code> attribute on any stylesheet element. In
    *                XQuery, it can be overridden using the <code>declare default collation</code>
    *                declaration in the query prolog, or via a setter method in class
    *                    {@link net.sf.saxon.query.StaticQueryContext}.</p>
    *            <p>If no value is specified, the Unicode codepoint collation is used.</p>
    *        
    **/

    public final static String DEFAULT_COLLATION = 
        "http://saxon.sf.net/feature/defaultCollation";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p> This determines the collection that is used when the <code>fn:collection()</code>
    *                function is called with no arguments; the effect is the same as if it were called
    *                passing the URI that is the value of this configuration property.</p>
    *        
    **/

    public final static String DEFAULT_COLLECTION = 
        "http://saxon.sf.net/feature/defaultCollection";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p> This determines the country that is used by <code>format-date()</code> and similar
    *                functions if no country code is supplied explicitly. If no value is given for this
    *                property, the default is taken from the Java Locale, which in turn typically depends
    *                on settings for the current user in the operating system.</p>
    *        
    **/

    public final static String DEFAULT_COUNTRY = 
        "http://saxon.sf.net/feature/defaultCountry";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option determines the language that is used by <code>format-date()</code>,
    *                    <code>xsl:number</code> and similar constructs if no language code is supplied
    *                explicitly. If no value is given for this property, the default is taken from the
    *                Java Locale, which in turn typically depends on settings for the current user in the
    *                operating system.</p>
    *        
    **/

    public final static String DEFAULT_LANGUAGE = 
        "http://saxon.sf.net/feature/defaultLanguage";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option is set to indicate that bytecode generation should be run in display
    *                mode. The effect is to output files (one per class) containing a human-readable
    *                print of the generated bytecode. The files are placed in the directory identified by
    *                the <code>DEBUG_BYTE_CODE_DIR</code> option.</p>
    *        
    **/

    public final static String DISPLAY_BYTE_CODE = 
        "http://saxon.sf.net/feature/displayByteCode";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>If true, the XML parser is requested to perform validation of source documents
    *                against their DTD. Default is false.</p>
    *            <p>This option establishes a default for use whenever source documents (not stylesheets
    *                or schema documents) are parsed. The option can be overridden for individual
    *                documents by setting the {@link net.sf.saxon.lib.ParseOptions} for that
    *                individual document, for example from a <code>URIResolver</code>.</p>
    *        
    **/

    public final static String DTD_VALIDATION = 
        "http://saxon.sf.net/feature/validation";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option determines whether DTD validation failures should be treated as
    *                recoverable. If the option is set, a validation failure is reported as a warning
    *                rather than an error. The default is false.</p>
    *            <p>This option establishes a default for use whenever source documents (not stylesheets
    *                or schema documents) are parsed. The option can be overridden for individual
    *                documents by setting the {@link net.sf.saxon.lib.ParseOptions} for that
    *                individual document, for example from a <code>URIResolver</code>.</p>
    *        
    **/

    public final static String DTD_VALIDATION_RECOVERABLE = 
        "http://saxon.sf.net/feature/dtd-validation-recoverable";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The supplied class is instantiated and the resulting <code>EntityResolver</code> is
    *                used whenever Saxon itself creates an <code>XMLReader</code> for parsing source
    *                documents. It is not used with a user-supplied <code>XMLReader</code>.</p>
    *            <p>The default value is {@link net.sf.saxon.lib.EntityResolver}. This is an entity
    *                resolver that recognizes the names of many standard W3C DTDs and external entity
    *                files, and resolves them against local copies issued with the Saxon software, to
    *                avoid the need to fetch them from the web.</p>
    *            <p>The property can be set to a zero-length string, in which case no
    *                    <code>EntityResolver</code> will be used.</p>
    *
    *        
    **/

    public final static String ENTITY_RESOLVER_CLASS = 
        "http://saxon.sf.net/feature/entityResolverClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Setting the <code>ENVIRONMENT_VARIABLE_RESOLVER</code> causes the supplied object to
    *                be registered as the environment variable resolver for the
    *                    <code>Configuration</code>. The setting is global: it affects all queries and
    *                transformations using this configuration.</p>
    *            <p>The environment variable resolver is used when the XPath functions
    *                    <code>available-environment-variables()</code> or
    *                    <code>environment-variable()</code> are called. Saxon essentially delegates the
    *                evaluation of the function to the external resolver.</p>
    *        
    **/

    public final static String ENVIRONMENT_VARIABLE_RESOLVER = 
        "http://saxon.sf.net/feature/environmentVariableResolver";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Setting <code>ENVIRONMENT_VARIABLE_RESOLVER_CLASS</code> causes an instance of the
    *                supplied class to be created, and registered as the environment variable resolver
    *                for the <code>Configuration</code>. The setting is global: it affects all queries
    *                and transformations using this configuration.</p>
    *            <p>The environment variable resolver is used when the XPath functions
    *                    <code>available-environment-variables()</code> or
    *                    <code>environment-variable()</code> are called. Saxon essentially delegates the
    *                evaluation of the function to the external resolver.</p>
    *        
    **/

    public final static String ENVIRONMENT_VARIABLE_RESOLVER_CLASS = 
        "http://saxon.sf.net/feature/environmentVariableResolverClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p><code>ERROR_LISTENER_CLASS</code> is the name of the class used to implement the JAXP
    *                    <code>ErrorListener</code>. This is used both at compile time and at run-time.
    *                Currently if this option is specified, the class is instantiated, and the same
    *                instance is used for all processes running under this configuration. This may change
    *                in future so that a new instance is created for each compilation or evaluation.</p>
    *            <p>Finer control can be obtained by setting the <code>ErrorListener</code> for a
    *                specific XSLT or XQuery compilation or evaluation.</p>
    *        
    **/

    public final static String ERROR_LISTENER_CLASS = 
        "http://saxon.sf.net/feature/errorListenerClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p><code>EXPAND_ATTRIBUTE_DEFAULTS</code> determines whether fixed and default values
    *                defined in a schema or DTD will be expanded (both on input and on output documents,
    *                if validation is requested). By default (and for conformance with the specification)
    *                validation against a DTD or schema will cause default values defined in the schema
    *                or DTD to be inserted into the document. Setting this feature to false suppresses
    *                this behavior. In the case of DTD-defined defaults this only works if the XML parser
    *                reports whether each attribute was specified in the source or generated by expanding
    *                a default value. Not all XML parsers report this information.</p>
    *        
    **/

    public final static String EXPAND_ATTRIBUTE_DEFAULTS = 
        "http://saxon.sf.net/feature/expandAttributeDefaults";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p><code>EXPATH_FILE_DELETE_TEMPORARY_FILES</code> determines whether temporary files
    *                and directories created in the EXPath File module should be automatically deleted on
    *                closure of the JVM.</p>
    *            <p>The default value is <b>false</b>, to align with the standard. The setting
    *                    <b>false</b> is recommended when external 'sweep-up' features aren't
    *                available.</p>
    *        
    **/

    public final static String EXPATH_FILE_DELETE_TEMPORARY_FILES = 
        "http://saxon.sf.net/feature/expathFileDeleteTemporaryFiles";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>By default, Saxon-EE attempts to generate Java bytecode for evaluation of parts of a
    *                query or stylesheet that are amenable to such treatment. Setting this option to
    *                false disables this.</p>
    *        
    **/

    public final static String GENERATE_BYTE_CODE = 
        "http://saxon.sf.net/feature/generateByteCode";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>If this option is set to true, then when a <code>SAXSource</code> is supplied as the
    *                input to an XSLT transformation, Saxon will ignore the <code>XMLReader</code>
    *                supplied in the <code>SAXSource</code> (in fact, it will modify the supplied
    *                    <code>SAXSource</code> setting the <code>XMLReader</code> to null) and use an
    *                    <code>XMLReader</code> created using the value of the
    *                    <code>SOURCE_PARSER_CLASS</code> option in preference.</p>
    *            <p>The defining use case for this feature is when calling a Saxon transformation from
    *                Ant. Ant always supplies the source document as a <code>SAXSource</code> using a
    *                parser instantiated using the default JAXP mechanism. A different parser set using
    *                the property <code>http://saxon.sf.net/feature/sourceParserClass</code> will
    *                normally be ignored in this case; setting the <code>ignoreSAXSourceParser</code>
    *                option overrides this. This is especially useful if the input format is not in fact
    *                XML, but some other format converted to a SAX event stream by means of a custom
    *                parser.</p>
    *        
    **/

    public final static String IGNORE_SAX_SOURCE_PARSER = 
        "http://saxon.sf.net/feature/ignoreSAXSourceParser";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p><code>LAZY_CONSTRUCTION_MODE</code> determines whether temporary trees are
    *                constructed lazily. The default setting is false; there are a few situations (but
    *                not many) where setting this to true can give a performance benefit (especially a
    *                memory saving).</p>
    *            <p>The option is most likely to be effective when executing XQuery in "pull" mode, that
    *                is, when the client calls the query processor to deliver the result as a stream of
    *                nodes, rather than running the query and piping the results into a serializer.</p>
    *        
    **/

    public final static String LAZY_CONSTRUCTION_MODE = 
        "http://saxon.sf.net/feature/lazyConstructionMode";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p><code>LICENSE_FILE_LOCATION</code> holds the filename in which the Saxon license file
    *                is held. This is the full file name, for example
    *                    <code>c:/saxon/license/license.lic</code>. Setting this property causes Saxon to
    *                immediately read the specified file and register the license data, assuming it can
    *                be found at this location. The property is not recognized for reading, and it is not
    *                recognized for writing except in Saxon-PE and Saxon-EE.</p>
    *        
    **/

    public final static String LICENSE_FILE_LOCATION = 
        "http://saxon.sf.net/feature/licenseFileLocation";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Default is false. If true, line and column number information is retained for all
    *                source documents. This information is accessible using the
    *                    <code>saxon:line-number()</code> and <code>saxon:column-number()</code>
    *                extension functions.</p>
    *            <p>Note that the information is only as good as the XML parser supplies. SAX parsers
    *                generally report the position of an element node using the line and column number of
    *                the ">" character that forms the last character of the start tag.</p>
    *        
    **/

    public final static String LINE_NUMBERING = 
        "http://saxon.sf.net/feature/linenumbering";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Use the specified <code>Receiver</code> to process the output from
    *                    <code>xsl:message</code>. The class must implement the
    *                    <code>net.sf.saxon.event.Receiver</code> interface. This interface is similar to
    *                a SAX <code>ContentHandler</code>, in that it takes a stream of events to generate
    *                output.</p>
    *            <p> By default the standard XML emitter is used, configured to write to the standard
    *                error stream, and to include no XML declaration. </p>
    *            <p>In general the content of a message is an XML fragment. Each message is output as a
    *                new document. The sequence of calls to this <code>Receiver</code> is as follows:
    *                there is a single <code>open()</code> call at the start of the transformation, and a
    *                single <code>close()</code> call at the end; and each evaluation of an
    *                    <code>xsl:message</code> instruction starts with a <code>startDocument()</code>
    *                call and ends with <code>endDocument()</code>. </p>
    *            <p>The <code>startDocument()</code> event has a <code>properties</code> argument
    *                indicating whether <code>terminate="yes"</code> was specified, and the
    *                    <code>locationId</code> on calls such as <code>startElement()</code> and
    *                    <code>characters()</code> can be used to identify the location in the stylesheet
    *                where the message data originated (this is achieved by passing the supplied
    *                    <code>locationId</code> in a call to
    *                    <code>getPipelineConfiguration().getLocator().getSystemId(locationId)</code>, or
    *                to <code>getLineNumber()</code> on the same object). </p>
    *            <p>Select the class <code>net.sf.saxon.event.MessageWarner</code> to have
    *                    <code>xsl:message</code> output notified to the JAXP <code>ErrorListener</code>,
    *                as described in the JAXP documentation.</p>
    *        
    **/

    public final static String MESSAGE_EMITTER_CLASS = 
        "http://saxon.sf.net/feature/messageEmitterClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Affects XQuery only. An instance of a user-written class implementing Saxon's
    *                    {@link net.sf.saxon.lib.ModuleURIResolver} interface. This is used to
    *                process any URIs used in <code>import module</code> directives in XQuery.</p>
    *        
    **/

    public final static String MODULE_URI_RESOLVER = 
        "http://saxon.sf.net/feature/moduleURIResolver";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Affects XQuery only. The name of a user-written class implementing Saxon's
    *                    {@link net.sf.saxon.lib.ModuleURIResolver} interface. This is used to
    *                process any URIs used in <code>import module</code> directives in XQuery.</p>
    *        
    **/

    public final static String MODULE_URI_RESOLVER_CLASS = 
        "http://saxon.sf.net/feature/moduleURIResolverClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Affects schema construction (whether for standalone validation, or in the context of
    *                XSLT or XQuery). If set to true, the schema processor attempts to fetch a schema
    *                document appearing in an <code>xs:import</code> directive, whether or not a schema
    *                for that namespace has already been loaded, unless the absolute URI formed from the
    *                    <code>schemaLocation</code> is the same as the absolute URI that was used to
    *                load that namespace. If set to false, the schema processor ignores the
    *                    <code>schemaLocation</code> on an <code>xs:import</code> declaration if schema
    *                components for the requested namespace are already available. Note that setting the
    *                value to true might cause spurious errors due to like-named schema components being
    *                loaded more than once. On the other hand, setting the value to false might result in
    *                validation failing because schema components are missing.</p>
    *
    *            <p>Note: Both settings are conformant with the W3C recommendation, which leaves the
    *                details implementation-defined. It is possible (and advisable) to write schemas in
    *                such a way that this setting makes no difference, by ensuring that all imports for a
    *                particular namespace go via a "home" schema document for that namespace, where the
    *                home schema document contains <code>xs:include</code> declarations for all the
    *                schema documents defining components in that namespace.</p>
    *
    *        
    **/

    public final static String MULTIPLE_SCHEMA_IMPORTS = 
        "http://saxon.sf.net/feature/multipleSchemaImports";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Indicates that the supplied <code>NamePool</code> should be used as the target
    *                (run-time) <code>NamePool</code> by all stylesheets compiled (using
    *                    <code>newTemplates()</code>) after this call on <code>setAttribute</code>.
    *                Normally a single system-allocated <code>NamePool</code> is used for all stylesheets
    *                compiled while the Java VM remains loaded; this attribute allows user control over
    *                the allocation of name pools. Note that source trees used as input to a
    *                transformation must be built using the same <code>NamePool</code> that is used when
    *                the stylesheet is compiled: this will happen automatically if the input to a
    *                transformation is supplied as a <code>SAXSource</code> or <code>StreamSource</code>
    *                but it is under user control if you build the source tree yourself.</p>
    *            <p>This option can be used to make two <code>Configuration</code> objects share a
    *                    <code>NamePool</code> even though they differ in other respects.</p>
    *        
    **/

    public final static String NAME_POOL = 
        "http://saxon.sf.net/feature/namePool";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p><code>OCCURRENCE_LIMITS</code> determines the largest values of
    *                    <code>minOccurs</code> and <code>maxOccurs</code> that can be accommodated when
    *                compiling an "expanded" finite state machine to represent an XSD content model
    *                grammar. These limits do not apply in the common cases where the grammar can be
    *                implemented using a counting finite-state-machine, but in those cases where this is
    *                not possible, any <code>minOccurs</code> value greater than the first integer is
    *                reduced to the value of the first integer, and any <code>maxOccurs</code> value
    *                greater than the second integer is treated as "unbounded".</p>
    *
    *            <p>Setting these values too high may cause an <code>OutOfMemoryException</code> since
    *                the size of the finite state machine constructed by Saxon increases linearly with
    *                the values of <code>minOccurs</code> and <code>maxOccurs</code>.</p>
    *        
    **/

    public final static String OCCURRENCE_LIMITS = 
        "http://saxon.sf.net/feature/occurrenceLimits";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>A string whose value is an integer in the range 0 (no optimization) to 10 (full
    *                optimization); currently all values other than 0 result in full optimization but
    *                this is likely to change in future. The default is full optimization; this feature
    *                allows optimization to be suppressed in cases where reducing compile time is
    *                important, or where optimization gets in the way of debugging, or causes extension
    *                functions with side-effects to behave unpredictably. (Note however, that even with
    *                no optimization, lazy evaluation may still cause the evaluation order to be not as
    *                expected.) </p>
    *        
    **/

    public final static String OPTIMIZATION_LEVEL = 
        "http://saxon.sf.net/feature/optimizationLevel";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The supplied <code>OutputURIResolver</code> will be used to resolve URIs of secondary
    *                result documents selected in the <code>href</code> attribute of the XSLT
    *                    <code>xsl:result-document</code> instruction.</p>
    *        
    **/

    public final static String OUTPUT_URI_RESOLVER = 
        "http://saxon.sf.net/feature/outputURIResolver";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The supplied class will be instantiated, and the resulting
    *                    <code>OutputURIResolver</code> will be used to resolve URIs of secondary result
    *                documents selected in the <code>href</code> attribute of the XSLT
    *                    <code>xsl:result-document</code> instruction.</p>
    *        
    **/

    public final static String OUTPUT_URI_RESOLVER_CLASS = 
        "http://saxon.sf.net/feature/outputURIResolverClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>If true, calls on the <code>doc()</code> and <code>document()</code> functions, if
    *                their arguments are known at compile time, will be evaluated at compile time, and
    *                the resulting document will be stored as part of the Saxon
    *                    {@link net.sf.saxon.Configuration} and shared by all queries and
    *                transformations running within that <code>Configuration</code>. This is useful for
    *                reference documents that have stable content and are used by many different queries
    *                and transformations. The default is false, which means each query or transformation
    *                will reload the document from disk.</p>
    *            <p>In XSLT 3.0 a better way of having external documents pre-loaded at stylesheet
    *                compile time is to use the new facility of static global variables.</p>
    *        
    **/

    public final static String PRE_EVALUATE_DOC_FUNCTION = 
        "http://saxon.sf.net/feature/preEvaluateDocFunction";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option has no effect on the Java platform. The default is <b>true</b>. When
    *                running on the .NET platform, if the option is true it causes the Apache Xerces
    *                parser (cross-compiled using IKVMC) to be used in preference to the .NET XML parser.
    *                If false the .NET XML parser (<code>System.Xml.XmlTextReader</code>) is used. One
    *                reason for providing this option is that the .NET XML parser does not report ID
    *                attributes, which means that the <code>id()</code> function does not work.</p>
    *        
    **/

    public final static String PREFER_JAXP_PARSER = 
        "http://saxon.sf.net/feature/preferJaxpParser";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>True if the the standard URI resolver is to recognize query parameters included in
    *                the URI (for example, <code>?val=strict</code>). Such parameters can then be used in
    *                URIs passed to the <code>doc()</code> or <code>document()</code> functions. For
    *                details of the query parameters available, see <xref>Source
    *                    Documents</xref>. The default is false.</p>
    *            <p>This option has no effect if a user-supplied <code>URIResolver</code> is in use,
    *                unless the user-supplied <code>URIResolver</code> chooses to inherit this
    *                functionality from the standard <code>URIResolver</code>.</p>
    *            <p>Allowed parameters include <code>validation=strict|lax|strip</code> to perform schema
    *                validation, <code>strip-space=yes|ignorable|no</code> to control whitespace
    *                stripping, and <code>xinclude=yes|no</code> to control whether XInclude processing
    *                takes place (assuming the XML parser supports it).</p>
    *        
    **/

    public final static String RECOGNIZE_URI_QUERY_PARAMETERS = 
        "http://saxon.sf.net/feature/recognize-uri-query-parameters";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>An integer, one of {@link net.sf.saxon.Configuration#RECOVER_SILENTLY},
    *                    {@link net.sf.saxon.Configuration#RECOVER_WITH_WARNINGS}, or
    *                    {@link net.sf.saxon.Configuration#DO_NOT_RECOVER}. Indicates the policy for
    *                handling dynamic errors that the XSLT specification defines as recoverable. 0 means
    *                recover silently; 1 means recover after signalling a warning to the
    *                    <code>ErrorListener</code>; 2 means treat the error as fatal. An example of a
    *                recoverable error is when two template rules match the same node.</p>
    *            <p>Note that XSLT 3.0 has eliminated all "recoverable errors" from the
    *                specification.</p>
    *        
    **/

    public final static String RECOVERY_POLICY = 
        "http://saxon.sf.net/feature/recoveryPolicy";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Indicates the policy for handling dynamic errors that the XSLT specification defines
    *                as recoverable. "recoverSilently" means recover silently; "recoverWithWarnings"
    *                means recover after signalling a warning to the <code>ErrorListener</code>;
    *                "doNotRecover" means treat the error as fatal. An example of a recoverable error is
    *                when two template rules match the same node. </p>
    *            <p>Note that XSLT 3.0 has eliminated all "recoverable errors" from the
    *                specification.</p>
    *        
    **/

    public final static String RECOVERY_POLICY_NAME = 
        "http://saxon.sf.net/feature/recoveryPolicyName";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Indicates the maximum number of threads to be used for processing
    *                    <code>xsl:result-document</code> instructions in parallel. If the maximum number
    *                of threads are already in use, the <code>xsl:result-document</code> instruction will
    *                be executed synchronously within its parent thread.</p>
    *            <p>The default value is initialized to
    *                    <code>Runtime.getRuntime().availableProcessors()</code> which is intended to
    *                represent the number of "processors" (under some definition) available from the
    *                hardware.</p>
    *            <p>The limit applies per <code>Configuration</code>. If multiple workloads are running
    *                on the same server under separate Saxon <code>Configuration</code> objects, then it
    *                may be desirable to lower the limit.</p>
    *            <p>Setting a value of zero or one suppresses multithreading entirely. This can also be
    *                achieved (for a specific <code>xsl:result-document</code> instruction) by setting
    *                the attribute <code>saxon:asynchronous="no"</code> in the stylesheet. Suppressing
    *                multithreading may be desirable in a stylesheet that calls extension functions with
    *                side-effects.</p>
    *        
    **/

    public final static String RESULT_DOCUMENT_THREADS = 
        "http://saxon.sf.net/feature/resultDocumentThreads";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>If set to true, indicates that when input is obtained from a SAX parser, the
    *                DTD-based attribute type notified by the XML parser should be used to set the type
    *                annotation of the resulting node: for example a DTD type of NMTOKENS results in a
    *                type annotation of xs:NMTOKENS. </p>
    *            <p>This option is retained for backwards compatibility (at some time in the past, it was
    *                the default), but is deprecated.</p>
    *        
    **/

    public final static String RETAIN_DTD_ATTRIBUTE_TYPES = 
        "http://saxon.sf.net/feature/retain-dtd-attribute-types";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The supplied <code>SchemaURIResolver</code> will be used to resolve URIs of schema
    *                documents referenced in <code>xsl:import-schema</code> declarations in XSLT,
    *                    <code>import schema</code> in XQuery, references from one schema document to
    *                another using <code>xs:include</code> or <code>xs:import</code>, and references from
    *                an instance document to a schema using <code>xsi:schemaLocation</code>.</p>
    *        
    **/

    public final static String SCHEMA_URI_RESOLVER = 
        "http://saxon.sf.net/feature/schemaURIResolver";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The name of a class that implements the interface <code>SchemaURIResolver</code>;
    *                this class will be instantiated and the resulting instance will be used as the value
    *                of the {@link FeatureKeys#SCHEMA_URI_RESOLVER} property.</p>
    *        
    **/

    public final static String SCHEMA_URI_RESOLVER_CLASS = 
        "http://saxon.sf.net/feature/schemaURIResolverClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Indicates whether and how schema validation should be applied to source
    *                documents.</p>
    *        
    **/

    public final static String SCHEMA_VALIDATION = 
        "http://saxon.sf.net/feature/schema-validation";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Indicates whether and how schema validation should be applied to source
    *                documents.</p>
    *        
    **/

    public final static String SCHEMA_VALIDATION_MODE = 
        "http://saxon.sf.net/feature/schema-validation-mode";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The class will be instantiated and the resulting <code>SerializerFactory</code> will
    *                be used to create the serialization pipeline for XSLT and XQuery results. By
    *                subclassing the standard <code>SerializerFactory</code> it is possible to customize
    *                many aspects of the output produced by the Serializer, or to introduce new
    *                serialization methods and parameters.</p>
    *        
    **/

    public final static String SERIALIZER_FACTORY_CLASS = 
        "http://saxon.sf.net/feature/serializerFactoryClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The class will be instantiated. If it is an <code>XMLReader</code> it is used
    *                directly; if it is a <code>SAXParserFactory</code> it is used to instantiate an
    *                    <code>XMLReader</code>. The resulting <code>XMLReader</code> will be used to
    *                parse source documents (that is, the principal source document plus any secondary
    *                source documents read using the <code>doc()</code>, <code>document()</code>, or
    *                    <code>collection()</code> function).</p>
    *            <p>Note that the selected parser is used only when the input is supplied in the form of
    *                a <code>StreamSource</code>; it is ignored when a <code>SAXSource</code> with a
    *                pre-initialized <code>XMLReeader</code> is supplied. A consequence is that this
    *                configuration option has no effect when running transformations from an Ant script,
    *                since the Ant <code>xslt</code> task always supplies the input in the form of a
    *                    <code>SAXSource</code>.</p>
    *        
    **/

    public final static String SOURCE_PARSER_CLASS = 
        "http://saxon.sf.net/feature/sourceParserClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>On interfaces that allow an <code>org.xml.sax.Source</code> to be supplied, if a kind
    *                of <code>Source</code> is provided that Saxon does not recognize, it will be passed
    *                to the user-supplied <code>SourceResolver</code>, which has the opportunity to
    *                convert it to a kind of <code>Source</code> that Saxon does recognize. This allows
    *                new kinds of input to be supplied as input to Saxon's query, transformation, and
    *                validation engines.</p>
    *        
    **/

    public final static String SOURCE_RESOLVER_CLASS = 
        "http://saxon.sf.net/feature/sourceResolverClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p><code>STANDARD_ERROR_OUTPUT_FILE</code> is the name of a file to which Saxon will
    *                redirect output that would otherwise go to the operating system standard error
    *                stream (System.err). This is the fallback destination for various tracing and
    *                diagnostic output. In some cases a more specific mechanism exists to select the
    *                destination for particular kinds of output.</p>
    *            <p>Note that if the <code>Configuration</code> is used in more than one processing
    *                thread, the messages from different threads will be interleaved in the output file.
    *                A more selective approach is to use a different <code>ErrorListener</code> in
    *                different processing threads, and arrange for each <code>ErrorListener</code> to
    *                write to its own logging destination.</p>
    *        
    **/

    public final static String STANDARD_ERROR_OUTPUT_FILE = 
        "http://saxon.sf.net/feature/standardErrorOutputFile";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p><code>STREAMABILITY</code> determines the test that Saxon applies to determine
    *                whether a construct is streamable, in cases where streaming is requested for example
    *                by use of the <code>xsl:stream</code> instruction, or by specifying
    *                    <code>streamable="yes"</code> on constructs such as <code>xsl:mode</code> and
    *                    <code>xsl:accumulator</code>.</p>
    *            <p>The value "standard" means that Saxon applies the rules in the W3C XSLT 3.0
    *                specification as closely as possible. (Exact compliance is not always possible.)</p>
    *            <p>The value "extended" means that use of Saxon streaming extensions is permitted. This
    *                is the default when using Saxon-EE with a suitable license.</p>
    *            <p>The value "off" means that all constructs are treated as non-streamable. This is the
    *                only option available when using a Saxon version or license that does not enable
    *                streaming.</p>
    *            <p>Whichever option is chosen, the <code>STREAMING_FALLBACK</code> option can be used to
    *                control what happens when code is deemed non-streamable; it provides a choice
    *                between throwing a static (compile-time) error, and falling back to a non-streaming
    *                implementation.</p>
    *        
    **/

    public final static String STREAMABILITY = 
        "http://saxon.sf.net/feature/streamability";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>If the <code>STREAMING_FALLBACK</code> option is set, then constructs for which
    *                streaming is requested (such as templates in a streaming mode, the
    *                    <code>xsl:stream</code> instruction, and streamable accumulators) will be
    *                executed in non-streaming mode if the code is not actually streamable. A
    *                compile-time warning will always be given when the fallback option is taken.</p>
    *        
    **/

    public final static String STREAMING_FALLBACK = 
        "http://saxon.sf.net/feature/streamingFallback";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Indicates whether all whitespace, no whitespace, or whitespace in elements defined in
    *                a DTD or schema as having element-only content should be stripped from source
    *                documents. The default is "ignorable". This whitespace stripping is additional to
    *                any stripping done as a result of the <code>xsl:strip-space</code> declaration in an
    *                XSLT stylesheet.</p>
    *        
    **/

    public final static String STRIP_WHITESPACE = 
        "http://saxon.sf.net/feature/strip-whitespace";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The class will be instantiated. If it is an <code>XMLReader</code> it is used
    *                directly; if it is a <code>SAXParserFactory</code> it is used to instantiate an
    *                    <code>XMLReader</code>. The resulting <code>XMLReader</code> will be used to
    *                parse stylesheet documents (that is, the principal stylesheet module plus any
    *                secondary source documents read using <code>xsl:include</code> or
    *                    <code>xsl:import</code>) and also schema documents.</p>
    *        
    **/

    public final static String STYLE_PARSER_CLASS = 
        "http://saxon.sf.net/feature/styleParserClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This is set to true to suppress the warning otherwise issued by command-line
    *                interfaces indicating that an evaluation license is in use and is due to expire in a
    *                set number of days.</p>
    *        
    **/

    public final static String SUPPRESS_EVALUATION_EXPIRY_WARNING = 
        "http://saxon.sf.net/feature/suppressEvaluationExpiryWarning";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This is set to true to suppress the warning when there is no commonality between the
    *                namespaces used in stylesheet match patterns and the namespaces used in the source
    *                document.</p>
    *        
    **/

    public final static String SUPPRESS_XSLT_NAMESPACE_CHECK = 
        "http://saxon.sf.net/feature/suppressXsltNamespaceCheck";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This is set to true to cause basic timing and tracing information is to be output to
    *                the standard error output stream. The name of the feature is poorly chosen, since
    *                much of the information that is output has nothing to do with timing, for example
    *                the names of output files for <code>xsl:result-document</code> are traced, as are
    *                the names of schema documents loaded.</p>
    *        
    **/

    public final static String TIMING = 
        "http://saxon.sf.net/feature/timing";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>If this option is set, Saxon will output (to the standard error output) progress
    *                information about its attempts to locate and disambiguate references to reflexive
    *                Java extension functions. This is useful for diagnostics if the XQuery or XSLT
    *                compiler is failing to locate user-written extension functions.</p>
    *        
    **/

    public final static String TRACE_EXTERNAL_FUNCTIONS = 
        "http://saxon.sf.net/feature/trace-external-functions";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>If this option is set, Saxon will output (to the standard error output) detailed
    *                information about the rewrites to the expression tree made by the optimizer. This
    *                information is mainly useful for internal system debugging, but it is also possible
    *                to digest it to analyze the ways in which the expression has been optimized for the
    *                purpose of performance analysis and tuning.</p>
    *        
    **/

    public final static String TRACE_OPTIMIZER_DECISIONS = 
        "http://saxon.sf.net/feature/trace-optimizer-decisions";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The <code>TraceListener</code> will be notified of significant events occurring
    *                during a query or transformation, for tracing or debugging purposes.</p>
    *            <p>Setting a <code>TraceListener</code> automatically sets the
    *                    {@link FeatureKeys#COMPILE_WITH_TRACING} option.</p>
    *            <p>Avoid this option if more than one transformation or query is running concurrently:
    *                use the feature {@link FeatureKeys#TRACE_LISTENER_CLASS} instead.
    *                Alternatively, it is possible to set a <code>TraceListener</code> for an individual
    *                query or transformation.</p>
    *        
    **/

    public final static String TRACE_LISTENER = 
        "http://saxon.sf.net/feature/traceListener";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The class will be instantiated once for each query or transformation, and the
    *                resulting <code>TraceListener</code> will be notified of significant events
    *                occurring during that query or transformation, for tracing or debugging
    *                purposes.</p>
    *            <p>Setting a <code>TraceListener</code> automatically sets the
    *                    {@link FeatureKeys#COMPILE_WITH_TRACING} option.</p>
    *        
    **/

    public final static String TRACE_LISTENER_CLASS = 
        "http://saxon.sf.net/feature/traceListenerClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Selects an implementation of the Saxon tree model. The default is
    *                    <code>TINY_TREE</code>.</p>
    *            <p>For running XQuery Update, use the linked tree, because it is the only implementation
    *                that is updateable.</p>
    *        
    **/

    public final static String TREE_MODEL = 
        "http://saxon.sf.net/feature/treeModel";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Selects an implementation of the Saxon tree model. The default is
    *                    <code>tinyTree</code>.</p>
    *            <p>For running XQuery Update, use the linked tree, because it is the only implementation
    *                that is updateable.</p>
    *        
    **/

    public final static String TREE_MODEL_NAME = 
        "http://saxon.sf.net/feature/treeModelName";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>An instance of the specified <code>URIResolver</code> class will be created, and used
    *                to resolve (dereference) all URIs specifed in calls to the <code>doc()</code> and
    *                    <code>document()</code> functions, as well as URIs used in
    *                    <code>xsl:include</code> and <code>xsl:import</code> and location hints for
    *                XQuery modules and XSD schema documents.</p>
    *        
    **/

    public final static String URI_RESOLVER_CLASS = 
        "http://saxon.sf.net/feature/uriResolverClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option determines whether a <code>TransformerHandler</code> created with this
    *                    <code>TransformerFactory</code> or <code>Configuration</code> recognizes the
    *                JAXP-defined processing instructions <code>Result.PI_DISABLE_OUTPUT_ESCAPING</code>
    *                and <code>Result.PI_ENABLE_OUTPUT_ESCAPING</code> in the input stream as
    *                instructions to disable or to re-enable output escaping. The default value is
    *                    <b>false</b>.</p>
    *        
    **/

    public final static String USE_PI_DISABLE_OUTPUT_ESCAPING = 
        "http://saxon.sf.net/feature/use-pi-disable-output-escaping";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option is relevant only when the TinyTree is used; it determines whether (for a
    *                validated document) a cache will be maintained containing the typed values of nodes.
    *                Typed values are held in the cache only for elements and attributes whose type is
    *                other than string, untypedAtomic, or anyURI. The default value is true. Setting this
    *                value to false can reduce memory requirements at the cost of requiring recomputation
    *                of typed values on each access.</p>
    *        
    **/

    public final static String USE_TYPED_VALUE_CACHE = 
        "http://saxon.sf.net/feature/use-typed-value-cache";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option determines whether or not to use the <code>xsi:schemaLocation</code>
    *                    and<code> xsi:noNamespaceSchemaLocation</code> attributes in an instance
    *                document to locate a schema for validation.</p>
    *            <p>Note, these attribute are only consulted if validation is requested; the presence of
    *                one of these attributes never by itself triggers validation.</p>
    *        
    **/

    public final static String USE_XSI_SCHEMA_LOCATION = 
        "http://saxon.sf.net/feature/useXsiSchemaLocation";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option determines whether non-fatal validation errors in XQuery or XSLT result
    *                documents should result in comments being inserted into the result tree. The
    *                command-line flag <code>-outval:recover</code> sets both this option and the
    *                    {@link FeatureKeys#VALIDATION_WARNINGS} option.</p>
    *        
    **/

    public final static String VALIDATION_COMMENTS = 
        "http://saxon.sf.net/feature/validation-comments";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option indicates (if true) that errors occuring while validating a final result
    *                tree are not to be treated as fatal.</p>
    *            <p>Regardless of the setting of this option, all validation errors are reported to the
    *                    <code>error()</code> method of the <code>ErrorListener</code>, and validation is
    *                terminated if the <code>error()</code> method throws an exception, or if the error
    *                limit set in the <code>ParseOptions</code> object is reached.</p>
    *            <p>This option primarily controls what happens at the end of a validation episode. If
    *                the validation episode detected one or more validation errors, then when this option
    *                is off, an exception is thrown, which will normally result in any query or
    *                stylesheet failing with a dynamic error, and no output file being written. If the
    *                option is on, no exception is thrown, and the output is written as if validation had
    *                been successful. Note in this case that any type annotations present in a result
    *                document are unreliable.</p>
    *
    *            <p>If this option is set when running XSLT or XQuery, it is ignored as far as input
    *                files are concerned: validation errors in input files are still fatal. However, if
    *                the option is set and a validation error occurs in a final output file, the output
    *                file is still written and the process terminates as if successful.</p>
    *
    *            <p>The detailed interpretation of this option changed in Saxon 9.5.</p>
    *
    *        
    **/

    public final static String VALIDATION_WARNINGS = 
        "http://saxon.sf.net/feature/validation-warnings";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Indicates whether a warning message should be notified (to the
    *                    <code>ErrorListener</code>) if running Saxon against an XSLT stylesheet that
    *                specifies <code>version="1.0"</code>. The warning that an XSLT 1.0 stylesheet is
    *                being processed using an XSLT 2.0 processor is output by default (because the W3C
    *                specification requires it), but it may be suppressed using this option.</p>
    *        
    **/

    public final static String VERSION_WARNING = 
        "http://saxon.sf.net/feature/version-warning";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Indicates whether source documents should have any XInclude directives expanded. The
    *                default is false. The option applies to all input XML documents, including
    *                stylesheets and schema documents. It can be overridden for individual documents
    *                using the {@link net.sf.saxon.lib.ParseOptions} class.</p>
    *            <p>This option relies on support in the underlying XML parser. If the XML parser does
    *                not support XInclude processing, the option is ignored.</p>
    *        
    **/

    public final static String XINCLUDE = 
        "http://saxon.sf.net/feature/xinclude-aware";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This determines the XML version used by the <code>Configuration</code>.</p>
    *            <p>Note that source documents specifying <code>xml version="1.0"</code> or
    *                    <code>"1.1"</code> are accepted regardless of this setting. The effect of this
    *                switch is to change the validation rules for types such as <code>xs:Name</code> and
    *                    <code>xs:NCName</code>, to change the characters allowed in names within XPath
    *                expressions (etc.), to change the meaning of <code>\i</code> and <code>\c</code> in
    *                regular expressions, and to determine whether the serializer allows XML 1.1
    *                documents to be constructed. </p>
    *            <p>The default is currently 1.0, but may change.</p>
    *        
    **/

    public final static String XML_VERSION = 
        "http://saxon.sf.net/feature/xml-version";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Sets the value of a parser feature flag. The feature name is any fully-qualified
    *                URI.</p>
    *            <p> For example if the parser supports a feature
    *                    <code>http://xml.org/sax/features/external-parameter-entities</code> then this
    *                can be set using the URI:
    *                    <code>http://saxon.sf.net/feature/parserFeature?uri=http://xml.org/sax/features/external-parameter-entities=true</code></p>
    *        
    **/

    public final static String XML_PARSER_FEATURE = 
        "http://saxon.sf.net/feature/parserFeature?uri=";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Sets the value of a parser property flag. The property name is any fully-qualified
    *                URI.</p>
    *            <p>For example if the parser supports a property
    *                    <code>http://apache.org/xml/properties/schema/external-schemaLocation</code>
    *                then this can be set using the URI:
    *                    <code>http://saxon.sf.net/feature/parserProperty?uri=http://apache.org/xml/properties/schema/external-schemaLocation="value"</code></p>
    *        
    **/

    public final static String XML_PARSER_PROPERTY = 
        "http://saxon.sf.net/feature/parserProperty?uri=";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>Determines whether XQuery Update syntax is accepted. If true, update syntax is
    *                accepted, if false, it is not accepted. Setting the value to true does not mean that
    *                the query has to use update syntax, only that it may do so.</p>
    *            <p>Note that XQuery Update syntax and XQuery 3.0 syntax cannot currently be mixed.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *            <p>On the command line, this option is combined with the option "discard" which
    *                indicates that updates are allowed, but the updates are not written back to
    *                filestore. This does not correspond to any option in the Java API, where writing an
    *                updated document back to filestore only happens if explicitly requested.</p>
    *        
    **/

    public final static String XQUERY_ALLOW_UPDATE = 
        "http://saxon.sf.net/feature/xqueryAllowUpdate";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This option defines the default value of the construction mode in the XQuery static
    *                context (overridable in the query prolog).</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *        
    **/

    public final static String XQUERY_CONSTRUCTION_MODE = 
        "http://saxon.sf.net/feature/xqueryConstructionMode";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property defines the default namespace for elements and types that are not
    *                qualified by a namespace prefix.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *        
    **/

    public final static String XQUERY_DEFAULT_ELEMENT_NAMESPACE = 
        "http://saxon.sf.net/feature/xqueryDefaultElementNamespace";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**<p>This property defines the default namespace for function names that are not
    *                qualified by a namespace prefix.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    **/

    public final static String XQUERY_DEFAULT_FUNCTION_NAMESPACE = 
        "http://saxon.sf.net/feature/xqueryDefaultFunctionNamespace";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property defines how the empty sequence is handled in XQuery sorting (the "order
    *                by" clause). If true, <code>()</code> comes at the start of the sorted sequence; if
    *                false, it comes last.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *        
    **/

    public final static String XQUERY_EMPTY_LEAST = 
        "http://saxon.sf.net/feature/xqueryEmptyLeast";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property defines the default value of the <code>inherit-namespaces</code>
    *                property in the XQuery static context.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *        
    **/

    public final static String XQUERY_INHERIT_NAMESPACES = 
        "http://saxon.sf.net/feature/xqueryInheritNamespaces";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property defines whether "boundary space" (insignificant space in direct element
    *                constructors) should be retained or not.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *        
    **/

    public final static String XQUERY_PRESERVE_BOUNDARY_SPACE = 
        "http://saxon.sf.net/feature/xqueryPreserveBoundarySpace";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property defines whether unused namespace declarations are retained by XQuery
    *                element copy operations.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *        
    **/

    public final static String XQUERY_PRESERVE_NAMESPACES = 
        "http://saxon.sf.net/feature/xqueryPreserveNamespaces";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property defines the default expected context item type for a query.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *        
    **/

    public final static String XQUERY_REQUIRED_CONTEXT_ITEM_TYPE = 
        "http://saxon.sf.net/feature/xqueryRequiredContextItemType";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>A query will automatically be schema-aware if it contains an <code>import
    *                    schema</code> declaration. This property allows a query to be marked as
    *                schema-aware even if it contains no <code>import schema</code> declaration. It is
    *                necessary for a query to be compiled as schema-aware if it is to handle typed
    *                (validated) input documents in which nodes have type annotations based on their
    *                schema-defined type.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *        
    **/

    public final static String XQUERY_SCHEMA_AWARE = 
        "http://saxon.sf.net/feature/xquerySchemaAware";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The specified class is instantiated to create an <code>ErrorListener</code>, and all
    *                reports of static errors in a query will go to this <code>ErrorListener</code>.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *            <p>In the absence of this property, the global <code>ErrorListener</code> specified as
    *                the value of the {@link #ERROR_LISTENER_CLASS} property is used.</p>
    *        
    **/

    public final static String XQUERY_STATIC_ERROR_LISTENER_CLASS = 
        "http://saxon.sf.net/feature/xqueryStaticErrorListenerClass";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property determines the version of XQuery used by the
    *                <code>Configuration</code>. In order to use XQuery 3.0, it is necessary both to set
    *                the XQuery compiler to process XQuery 3.0, and to specify XQuery 3.0 in the query
    *                prolog of each module that uses XQuery 3.0 features.</p>
    *            <p>This option can be set for a particular XQuery compilation. When the option is set at
    *                the <code>Configuration</code> level, it acts as a default.</p>
    *            <p>Note that XQuery 3.0 features cannot be used with XQuery Update.</p>
    *            <p>XQuery 3.0 is supported only in Saxon EE.</p>
    *        
    **/

    public final static String XQUERY_VERSION = 
        "http://saxon.sf.net/feature/xqueryVersion";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property determines the version of XML Schema used by the
    *                    <code>Configuration</code>. The default is XSD 1.0. If XSD 1.0 is selected, XSD
    *                1.1 features will be rejected, with the exception of the version control attributes
    *                that allow sections of the schema to be marked as requiring XSD 1.0 or XSD 1.1.</p>
    *        
    **/

    public final static String XSD_VERSION = 
        "http://saxon.sf.net/feature/xsd-version";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property indicates the name of a mode within a stylesheet in which execution
    *                (using template rules) should begin.</p>
    *            <p>This option can be set for a particular XSLT transformation. When the option is set
    *                at the <code>Configuration</code> (or on a <code>TransformerFactory</code>), it acts
    *                as a default.</p>
    *        
    **/

    public final static String XSLT_INITIAL_MODE = 
        "http://saxon.sf.net/feature/initialMode";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property indicates the name of a named template within a stylesheet where
    *                execution should begin.</p>
    *            <p>This option can be set for a particular XSLT transformation. When the option is set
    *                at the <code>Configuration</code> level (or on a <code>TransformerFactory</code>),
    *                it acts as a default.</p>
    *        
    **/

    public final static String XSLT_INITIAL_TEMPLATE = 
        "http://saxon.sf.net/feature/initialTemplate";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property indicates whether stylesheets should be compiled with the ability to
    *                handle schema-typed input documents. By default a stylesheet is compiled to handle
    *                such input if it contains an <code>xsl:import-schema</code> instruction, and not
    *                otherwise. It is necessary for a stylesheet to be compiled as schema-aware if it is
    *                to handle typed (validated) input documents in which nodes have type annotations
    *                based on their schema-defined type.</p>
    *            <p>This option can be set for a particular XSLT compilation. When the option is set at
    *                the <code>Configuration</code> level (or on a <code>TransformerFactory</code>), it
    *                acts as a default.</p>
    *        
    **/

    public final static String XSLT_SCHEMA_AWARE = 
        "http://saxon.sf.net/feature/xsltSchemaAware";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>The specified class is instantiated to create an <code>ErrorListener</code>, and all
    *                reports of static errors in a stylesheet will go to this
    *                <code>ErrorListener</code>.</p>
    *            <p>This option can be set for a particular XSLT compilation. When the option is set at
    *                the <code>Configuration</code> level (or on a <code>TransformerFactory</code>), it
    *                acts as a default.</p>
    *            <p>In the absence of this property, the global <code>ErrorListener</code> specified as
    *                the value of the {@link #ERROR_LISTENER_CLASS} property is used.</p>
    *        
    **/

    public final static String XSLT_STATIC_ERROR_LISTENER_CLASS = 
        "http://saxon.sf.net/feature/stylesheetErrorListener";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property defines a <code>URIResolver</code> used when dereferencing the URIs
    *                that appear in the <code>href</code> attributes of the <code>xsl:include</code> and
    *                    <code>xsl:import</code> declarations. Note that this defaults to the setting of
    *                the global <code>URI_RESOLVER</code> property.</p>
    *            <p>This option can be set for a particular XSLT compilation. When the option is set at
    *                the <code>Configuration</code> level (or on a <code>TransformerFactory</code>), it
    *                acts as a default.</p>
    *            <p>In the absence of this property, the global <code>URIResolver</code> specified as the
    *                value of the {@link #URI_RESOLVER_CLASS} property is used.</p>
    *        
    **/

    public final static String XSLT_STATIC_URI_RESOLVER_CLASS = 
        "http://saxon.sf.net/feature/stylesheetURIResolver";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


    /**
    *            <p>This property determines the version of XSLT to be supported by default.</p>
    *            <p>XSLT 3.0 is supported only in Saxon EE. If no value is specified for the property, an
    *                XSLT 2.0 or XSLT 3.0 processor is used depending on the value of the
    *                    <code>version</code> attribute of the <code>xsl:stylesheet</code> element.</p>
    *        
    **/

    public final static String XSLT_VERSION = 
        "http://saxon.sf.net/feature/xsltVersion";

// AUTO-GENERATED FROM FeatureKeys.xml - DO NOT EDIT THIS FILE


}
        